Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2457)

Unified Diff: content/browser/service_worker/embedded_worker_instance.h

Issue 2420253002: Rename shell namespace to service_manager (Closed)
Patch Set: . Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/service_worker/embedded_worker_instance.h
diff --git a/content/browser/service_worker/embedded_worker_instance.h b/content/browser/service_worker/embedded_worker_instance.h
index 705b77352985c18bf47b9bf8d1eabb9e9812b00f..65df84655372a5c558b0ffa041ec407f8a2b1c79 100644
--- a/content/browser/service_worker/embedded_worker_instance.h
+++ b/content/browser/service_worker/embedded_worker_instance.h
@@ -37,7 +37,7 @@ namespace IPC {
class Message;
}
-namespace shell {
+namespace service_manager {
class InterfaceProvider;
class InterfaceRegistry;
}
@@ -134,11 +134,12 @@ class CONTENT_EXPORT EmbeddedWorkerInstance {
// Resumes the worker if it paused after download.
void ResumeAfterDownload();
// Returns the shell::InterfaceRegistry and shell::InterfaceProvider for this
// worker. It is invalid to call this when the worker is not in STARTING or
// RUNNING status.
- shell::InterfaceRegistry* GetInterfaceRegistry();
- shell::InterfaceProvider* GetRemoteInterfaces();
+ service_manager::InterfaceRegistry* GetInterfaceRegistry();
+ service_manager::InterfaceProvider* GetRemoteInterfaces();
int embedded_worker_id() const { return embedded_worker_id_; }
EmbeddedWorkerStatus status() const { return status_; }
@@ -311,8 +312,8 @@ class CONTENT_EXPORT EmbeddedWorkerInstance {
int thread_id_;
// These are connected to the renderer process after OnThreadStarted.
- std::unique_ptr<shell::InterfaceRegistry> interface_registry_;
- std::unique_ptr<shell::InterfaceProvider> remote_interfaces_;
+ std::unique_ptr<service_manager::InterfaceRegistry> interface_registry_;
+ std::unique_ptr<service_manager::InterfaceProvider> remote_interfaces_;
// |client_| is used to send messages to the renderer process.
mojom::EmbeddedWorkerInstanceClientPtr client_;
« no previous file with comments | « content/browser/service_manager/service_manager_context.cc ('k') | content/browser/service_worker/embedded_worker_instance.cc » ('j') | no next file with comments »
@@ -134,11 +134,12 @@ class CONTENT_EXPORT EmbeddedWorkerInstance {
// Resumes the worker if it paused after download.
void ResumeAfterDownload();
- // Returns the shell::InterfaceRegistry and shell::InterfaceProvider for this
+ // Returns the service_manager::InterfaceRegistry and
+ // service_manager::InterfaceProvider for this
// worker. It is invalid to call this when the worker is not in STARTING or
// RUNNING status.

Powered by Google App Engine
This is Rietveld 408576698